=== modified file 'buildout.cfg'
--- buildout.cfg	2012-10-02 17:52:58 +0000
+++ buildout.cfg	2012-10-04 15:09:12 +0000
@@ -25,14 +25,10 @@
 prefer-final = true
 
 develop = .
-          /home/jw2328/devel/libdep-service/public-test-double
 
 [scripts]
 recipe = z3c.recipe.scripts
 # Test dependencies get added here
-eggs = libdep-service-python
-       libdep-service
-       testtools
-       treeshape
+eggs = libdep-service-python[testing]
 include-site-packages = false
 interpreter = py

=== modified file 'libdep_service_client/tests/test_client.py'
--- libdep_service_client/tests/test_client.py	2012-10-02 17:52:58 +0000
+++ libdep_service_client/tests/test_client.py	2012-10-04 15:09:12 +0000
@@ -1,5 +1,7 @@
-import json
-
+from testresources import (
+    FixtureResource,
+    ResourcedTestCase,
+    )
 from testtools import TestCase
 
 from djlibdep.test_double import LibdepServiceDouble
@@ -63,28 +65,36 @@
         self.assertEqual("Unknown alias: {}".format(alias), str(e))
 
 
-class ClientIntegrationTests(TestCase):
-
-    # FIXME: use a resource to avoid startup overhead on every test
+# This is implicit setup for the tests that share it, so keep
+# the data small and the use of it minimal.
+TEST_DATA = {
+    'v1/service_check': [({}, 'Hello world!')],
+    'v1/get_binaries_for_libraries': [
+            ({'libs': ['doesnotexist']}, '{}'),
+            ({'libs': ['libc.so.6']}, '{"libc.so.6": ["libc-bin"]}'),
+    ],
+}
+
+test_double_fixture = FixtureResource(LibdepServiceDouble(TEST_DATA))
+
+
+
+class ClientIntegrationTests(TestCase, ResourcedTestCase):
+
+    resources = [('double', test_double_fixture)]
 
     def test_get_binaries_for_libraries_found(self):
-        lib = 'libfoo.so.1'
-        binaries = '{"%s": ["libfoo-bin"]}' % (lib,)
-        test_data = {'v1/get_binaries_for_libraries': [
-            ({'libs': [lib]}, binaries),
-        ]}
-        server = self.useFixture(LibdepServiceDouble(test_data))
-        c = client.Client(server.base_url)
-        self.assertEqual(json.loads(binaries), c.get_binaries_for_libraries([lib]))
+        lib = 'libc.so.6'
+        c = client.Client(self.double.base_url)
+        self.assertEqual({"libc.so.6": ["libc-bin"]},
+                c.get_binaries_for_libraries([lib]))
 
     def test_get_binaries_for_libraries_missing(self):
-        lib = 'libfoo.so.1'
-        binaries = '{}'
-        test_data = {'v1/get_binaries_for_libraries': [
-            ({'libs': [lib]}, binaries),
-        ]}
-        server = self.useFixture(LibdepServiceDouble(test_data))
-        c = client.Client(server.base_url)
-        self.assertEqual(json.loads(binaries), c.get_binaries_for_libraries([lib]))
+        lib = 'doesnotexist'
+        c = client.Client(self.double.base_url)
+        self.assertEqual({}, c.get_binaries_for_libraries([lib]))
 
-    # TODO: tests for failure modes
+    def test_get_binaries_for_libraries_unheard(self):
+        lib = 'neverexisted'
+        c = client.Client(self.double.base_url)
+        self.assertEqual({}, c.get_binaries_for_libraries([lib]))

=== modified file 'setup.py'
--- setup.py	2012-08-28 16:30:58 +0000
+++ setup.py	2012-10-04 15:09:12 +0000
@@ -27,5 +27,11 @@
         # TODO: List scripts here
         ],
     zip_safe=False,
+    extras_require = {
+        'testing': [
+            'libdep-service[testing]',
+            'testtools',
+            ],
+        },
     packages=find_packages('.'),
 )

=== modified file 'versions.cfg'
--- versions.cfg	2012-10-01 18:34:11 +0000
+++ versions.cfg	2012-10-04 15:09:12 +0000
@@ -26,6 +26,7 @@
 lazr.authentication = 0.1.2
 lazr.restfulclient = 0.13.0
 lazr.uri = 1.0.3
+libdep-service = 0.1
 Markdown = 2.2.0
 oauth = 1.0.1
 oops = 0.0.10

